# Generated by Django 3.2.4 on 2025-04-15 10:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0023_auto_20250414_1018'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operationtypes',
            name='shortname',
            field=models.CharField(blank=True, max_length=300, null=True, verbose_name='Краткое наименование'),
        ),
    ]
